@@ -1,7 +1,7 @@
 package Dist::Zilla::Plugin::InsertBlock;
 
-our $DATE = '2015-03-21'; # DATE
-our $VERSION = '0.04'; # VERSION
+our $DATE = '2015-06-18'; # DATE
+our $VERSION = '0.05'; # VERSION
 
 use 5.010001;
 use strict;
@@ -11,7 +11,7 @@ use Moose;
 with (
     'Dist::Zilla::Role::FileMunger',
     'Dist::Zilla::Role::FileFinderUser' => {
-        default_finders => [':InstallModules', ':ExecFiles'],
+        default_finders => [':InstallModules', ':ExecFiles', ':TestFiles'],
     },
 );
 
@@ -78,7 +78,7 @@ Dist::Zilla::Plugin::InsertBlock - Insert a block of text from another file
 
 =head1 VERSION
 
-This document describes version 0.04 of Dist::Zilla::Plugin::InsertBlock (from Perl distribution Dist-Zilla-Plugin-InsertBlock), released on 2015-03-21.
+This document describes version 0.05 of Dist::Zilla::Plugin::InsertBlock (from Perl distribution Dist-Zilla-Plugin-InsertBlock), released on 2015-06-18.
 
 =head1 SYNOPSIS
 
